searchData={"items":[{"type":"module","title":"Imgproxy","doc":"`Imgproxy` generates urls for use with an [imgproxy](https://imgproxy.net) server.","ref":"Imgproxy.html"},{"type":"function","title":"Imgproxy.add_option/3","doc":"Add a [formatting option](https://docs.imgproxy.net/generating_the_url_advanced) to the `t:Imgproxy.t/0`.\n\nFor instance, to add the [padding](https://docs.imgproxy.net/generating_the_url_advanced?id=padding) option\nwith a 10px padding on all sides, you can use:\n\n    iex> img = Imgproxy.new(\"http://example.com/image.jpg\")\n    iex> Imgproxy.add_option(img, :padding, [10, 10, 10, 10]) |> to_string()\n    \"https://imgcdn.example.com/insecure/padding:10:10:10:10/aHR0cDovL2V4YW1wbGUuY29tL2ltYWdlLmpwZw\"","ref":"Imgproxy.html#add_option/3"},{"type":"function","title":"Imgproxy.crop/4","doc":"[Crop](https://docs.imgproxy.net/generating_the_url_advanced?id=crop) an image to the given width and height.\n\nAccepts an optional [gravity](https://docs.imgproxy.net/generating_the_url_advanced?id=gravity) parameter, by\ndefault it is \"ce:0:0\" for center gravity with no offset.","ref":"Imgproxy.html#crop/4"},{"type":"function","title":"Imgproxy.info_new/1","doc":"Generate a new `t:Imgproxy.t/0` struct for the given image source URL to fetch the\n[Info Endpoint](https://docs.imgproxy.net/usage/getting_info).","ref":"Imgproxy.html#info_new/1"},{"type":"function","title":"Imgproxy.new/1","doc":"Generate a new `t:Imgproxy.t/0` struct for the given image source URL.","ref":"Imgproxy.html#new/1"},{"type":"function","title":"Imgproxy.resize/4","doc":"[Resize](https://docs.imgproxy.net/generating_the_url_advanced?id=resize) an image to the given width and height.\n\nOptions include:\n  * type: \"fit\" (default), \"fill\", or \"auto\"\n  * enlarge: enlarge if necessary (`false` by default)","ref":"Imgproxy.html#resize/4"},{"type":"function","title":"Imgproxy.set_extension/2","doc":"Set the file extension (which will produce an image of that type).\n\nFor instance, setting the extension to \"png\" will result in a PNG being created:\n\n    iex> img = Imgproxy.new(\"http://example.com/image.jpg\")\n    iex> Imgproxy.set_extension(img, \"png\") |> to_string()\n    \"https://imgcdn.example.com/insecure/aHR0cDovL2V4YW1wbGUuY29tL2ltYWdlLmpwZw.png\"","ref":"Imgproxy.html#set_extension/2"},{"type":"function","title":"Imgproxy.set_gravity/4","doc":"Set the [gravity](https://docs.imgproxy.net/generating_the_url_advanced?id=gravity) option.","ref":"Imgproxy.html#set_gravity/4"},{"type":"function","title":"Imgproxy.to_string/1","doc":"Generate an imgproxy URL.","ref":"Imgproxy.html#to_string/1"},{"type":"function","title":"Example - Imgproxy.to_string/1","doc":"iex> Imgproxy.to_string(Imgproxy.new(\"https://placekitten.com/200/300\"))\n    \"https://imgcdn.example.com/insecure/aHR0cHM6Ly9wbGFjZWtpdHRlbi5jb20vMjAwLzMwMA\"","ref":"Imgproxy.html#to_string/1-example"},{"type":"type","title":"Imgproxy.dimension/0","doc":"A number of pixels to be used as a dimension.","ref":"Imgproxy.html#t:dimension/0"},{"type":"type","title":"Imgproxy.resize_opts/0","doc":"Provide type and enlarge configuration arguments to a resize option.","ref":"Imgproxy.html#t:resize_opts/0"},{"type":"type","title":"Imgproxy.t/0","doc":"","ref":"Imgproxy.html#t:t/0"},{"type":"task","title":"mix imgproxy.gen.secret","doc":"Generates a secret that could be used as a salt or key and prints it to the terminal.\n\n    $ mix imgproxy.gen.secret","ref":"Mix.Tasks.Imgproxy.Gen.Secret.html"},{"type":"function","title":"Mix.Tasks.Imgproxy.Gen.Secret.run/1","doc":"","ref":"Mix.Tasks.Imgproxy.Gen.Secret.html#run/1"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"v3.0.2 (2023-02-18) - Changelog","doc":"#","ref":"changelog.html#v3-0-2-2023-02-18"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Added support for the [Info Endpoint](https://docs.imgproxy.net/usage/getting_info) (#6)","ref":"changelog.html#enhancements"},{"type":"extras","title":"v3.0.1 (2022-01-17) - Changelog","doc":"#","ref":"changelog.html#v3-0-1-2022-01-17"},{"type":"extras","title":"Fixed - Changelog","doc":"* Fixed issue producing a compile warning","ref":"changelog.html#fixed"},{"type":"extras","title":"v3.0.0 (2021-09-15) - Changelog","doc":"#","ref":"changelog.html#v3-0-0-2021-09-15"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support for [advanced URL generation](https://docs.imgproxy.net/generating_the_url_advanced?id=generating-the-url-advanced)\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Hard-deprecations - Changelog","doc":"* No support for imgproxy before version 2.0.0\n   * The `Imgproxy` library API has changed significantly and does not have any backward compatibility before version 3.0.0","ref":"changelog.html#hard-deprecations"},{"type":"extras","title":"v2.0.0 (2020-05-24) - Changelog","doc":"#","ref":"changelog.html#v2-0-0-2020-05-24"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Code now works with OTP 24 and the updated `:crypto` library\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Hard-deprecations - Changelog","doc":"* No OTP versions below 22 are supported.","ref":"changelog.html#hard-deprecations"},{"type":"extras","title":"v1.0.0 (2020-05-23) - Changelog","doc":"#","ref":"changelog.html#v1-0-0-2020-05-23"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updated docs with specs to be more readable","ref":"changelog.html#enhancements"},{"type":"extras","title":"License","doc":"# MIT License\n\nCopyright (c) 2019 Brian Muller\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"},{"type":"extras","title":"Overview","doc":"# Imgproxy\n\n[![Build Status](https://github.com/bmuller/imgproxy/actions/workflows/ci.yml/badge.svg)](https://github.com/bmuller/imgproxy/actions/workflows/ci.yml)\n[![Module Version](https://img.shields.io/hexpm/v/imgproxy.svg)](https://hex.pm/packages/imgproxy)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/imgproxy/)\n\nImgproxy is an Elixir library that helps generate [imgproxy](https://github.com/DarthSim/imgproxy) URLs.  Before using this library, you should have a running imgproxy server.\n\n**Note:** As of version `3.0`, OTP `>= 22.1` and `imgproxy >= 2.0.0` are required.","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"To install Imgproxy, just add an entry to your `mix.exs`:\n\n``` elixir\ndef deps do\n  [\n    {:imgproxy, \"~> 3.0\"}\n  ]\nend\n```\n\n(Check [Hex](https://hex.pm/packages/imgproxy) to make sure you're using an up-to-date version number.)","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Overview","doc":"In your `config/config.exs` you can set a few options:\n\n``` elixir\nconfig :imgproxy,\n  prefix: \"https://imgcdn.example.com\",\n  key: \"cdf104fc78b7d7f6f0158c253612f5dsecretsecret...\",\n  salt: \"aad7034f611b7fc28c6d344f72ea19secretsecret...\"\n```\n\nThe `prefix` should be the location of the imgproxy server.  `key` and `salt` are only necessary if you are using [URL signatures](https://docs.imgproxy.net/signing_the_url).  To generate the key a key and salt, you can use:\n\n``` bash\n$ mix imgproxy.gen.secret\n```\n\nYou can use the output as your key or salt (ideally, just run the command twice, use the first output for your key and the second output for your salt).","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - Overview","doc":"Usage is simple - first generate an `Imgproxy` struct via `Imgproxy.new/1`, add any options you'd like, then convert to a string.\n\nExample:\n\n```elixir\n# Generate URL for an image, using defaults\nImgproxy.new(\"https://placekitten.com/200/300\") |> to_string()\n\n# Resize to 123x321\n\"https://placekitten.com/200/300\"\n|> Imgproxy.new()\n|> Imgproxy.resize(123, 321, type: \"fill\")\n|> to_string()\n\n\n# Crop and return a jpg\n\"https://placekitten.com/200/300\"\n|> Imgproxy.new()\n|> Imgproxy.crop(100, 100)\n|> Imgproxy.set_extension(\"jpg\")\n|> to_string()\n```","ref":"readme.html#usage"},{"type":"extras","title":"Running Tests - Overview","doc":"To run tests:\n\n``` shell\n$ mix test\n```","ref":"readme.html#running-tests"},{"type":"extras","title":"Reporting Issues - Overview","doc":"Please report all issues [on github](https://github.com/bmuller/imgproxy/issues).","ref":"readme.html#reporting-issues"},{"type":"extras","title":"Copyright and License - Overview","doc":"Copyright (c) 2019 Brian Muller\n\nThis work is free. You can redistribute it and/or modify it under the\nterms of the MIT License. See the [LICENSE.md](./LICENSE.md) file for more details.","ref":"readme.html#copyright-and-license"}],"content_type":"text/markdown"}